%bcond_with shared_libuv

%define major 8
%define minor 16
%define fix 1

%define node_prefix %{_libdir}/%{name}

Name: nodejs%{major}
Version: %{major}.%{minor}.%{fix}
Release: 1
License: MIT
Summary: Node.js JavaScript Runtime
Url: https://www.nodejs.org

Obsoletes: nodejs

BuildRequires: python2
BuildRequires: zlib-devel
BuildRequires: openssl-devel <= 1.1.0

%if %{with shared_libuv}
BuildRequires: libuv-devel
%endif

Requires: nodever

Source0: https://nodejs.org/dist/v%{major}.%{minor}.%{fix}/node-v%{major}.%{minor}.%{fix}.tar.gz

Patch0: nodejs8-nobody.patch
Patch1: nodejs8-libpath.patch
Patch2: nodejs8-cmsg-space.patch
Patch3: nodejs8-fswatch.patch
Patch4: nodejs8-EISDIR.patch

%description
Node.js is a JavaScript runtime built on Chrome V8 JavaScript engine. Node.js
uses an event-driven, non-blocking I/O model that makes it lightweight and
efficient.

%prep
%setup -q -n node-v%{version}

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

# Fix the wrong dependencies /bin/sh and /usr/bin/python
find . -type f | xargs perl -pi -e 's|/usr/bin/python|%{_bindir}/python2|g;s|#!/bin/sh|#!/QOpenSys/usr/bin/sh|g'

# Fix hardcoded node absolute path
# Yes, '-type f' is necessary as there's a directory named foo.js...
find . -type f -name "*.js" | xargs perl -pi -e 's|/usr/bin/env node|%{node_prefix}/bin/node|g'

%build

export CC=gcc
export CXX=g++

./configure \
  --prefix=%{node_prefix} \
  --dest-cpu=ppc64 \
  --without-snapshot \
  --without-perfctr \
  --shared-openssl \
  --shared-zlib \
  %{?with_shared_libuv:--shared-libuv} \
  # end

%make_build
# basic verification
./node -e "console.log(process.versions)"

%install

%make_install V=1 PORTABLE=1

%postun
if [ "$1" = "0" ] ; then
  ls -l /QOpenSys/pkgs/bin/node 2> /dev/null | grep %{node_prefix} >/dev/null
  if [ $? -eq 0 ]; then
    /QOpenSys/pkgs/bin/nodever auto &>/dev/null # set another available node effective
  fi
fi

%post
if [ ! -e "/QOpenSys/pkgs/bin/node" ] ; then
  ln -sf /QOpenSys/pkgs/lib/nodejs8/bin/node /QOpenSys/pkgs/bin/node
fi
if [ ! -e "/QOpenSys/pkgs/bin/npm" ] ; then
  ln -sf /QOpenSys/pkgs/lib/nodejs8/bin/npm /QOpenSys/pkgs/bin/npm
fi

%files
# Set the default owner to QSYS and group to *NONE
%defattr(-, qsys, *none)

%{node_prefix}

%changelog
* Tue Aug 20 2019 - Xu Meng <mengxumx@cn.ibm.com>
- update to v8.16.1

* Mon Mar 11 2019 - Xu Meng <mengxumx@cn.ibm.com>
- update to v8.15.1

* Thu Jan 17 2019 - Xu Meng <mengxumx@cn.ibm.com>
- call 'nodever auto' when uninstall

* Wed Jan 09 2019 - Xu Meng <mengxumx@cn.ibm.com>
- fix the EISDIR issue(https://github.com/nodejs/node/issues/25433)

* Fri Jan 04 2019 - Xu Meng <mengxumx@cn.ibm.com>
- update to v8.15.0

* Sun Dec 09 2018 - Xu Meng <mengxumx@cn.ibm.com>
- update to v8.14.0

* Mon Oct 08 2018 - Xu Meng <mengxumx@cn.ibm.com>
- update to v8.12.0

* Wed Aug 29 2018 - Xu Meng <mengxumx@cn.ibm.com>
- update to v8.11.4

* Thu Aug 23 2018 - Xu Meng <mengxumx@cn.ibm.com>
- make nodejs create the global links 

* Mon Aug 20 2018 - Xu Meng <mengxumx@cn.ibm.com>
- use fs.watchFile() instead of fs.watch() by default

* Mon Aug 06 2018 - Xu Meng <mengxumx@cn.ibm.com>
- fix the uv_resident_set_memory issue to support yarn

* Mon May 14 2018 - Xu Meng <mengxumx@cn.ibm.com>
- nodejs version control(nodever) support

* Mon May 14 2018 - Xu Meng <mengxumx@cn.ibm.com>
- enable inspector

* Wed Apr 25 2018 - Xu Meng <mengxumx@cn.ibm.com>
- fix shebang and cluster issues

* Thu Apr 19 2018 - Xu Meng <mengxumx@cn.ibm.com>
- fix the thread_cputime() issue

* Tue Apr 10 2018 - Jesse R. Gorzinski <jgorzins@us.ibm.com>
- ship nodejs8 in /QOpenSys/pkgs/lib/nodejs8

* Wed Mar 07 2018 - Xu Meng <mengxumx@cn.ibm.com>
- update to v8.9.4

* Fri Mar 02 2018 - Xu Meng <mengxumx@cn.ibm.com>
- update C compiler to gcc6

* Tue Jan 23 2018 - Xu Meng <mengxumx@cn.ibm.com>
- support dynamic linking libraries
